@@ -1,4 +1,5 @@
 from .dir import ext_dir
+from .extract import ext_extract
 from .makegit import ext_git
 from .download import ext_download
 from .template import ext_template
@@ -9,5 +10,6 @@ extension_handles = {
     'git':ext_git,
     'download':ext_download,
     'virtualenv':ext_virtualenv,
-    'tpl':ext_template
+    'tpl':ext_template,
+    'extract':ext_extract
 }
