@@ -1,5 +1,6 @@
 from extutils import get_filename
 from template import render
+from download import _download_file
 import os
 import requests
 import tarfile
@@ -42,6 +43,14 @@ SCHEMA = {
             'description': 'What type of file this is',
             'enum': EXTRACTORS.keys()
         },
+        'username': {
+            'description': 'Username to login with BASIC Auth',
+            'type':'string'
+        },
+        'password': {
+            'description': 'Password to use with BASIC Auth',
+            'type':'string'
+        },
         'copy': {
             'description': 'Where to copy files within this file to',
             'type': 'array',
@@ -68,14 +77,6 @@ SCHEMA = {
     'required': ['url']
 }
 
-def _download_file(url, handle):
-    r = requests.get(url, stream=True)
-
-    for chunk in r.iter_content(chunk_size=4096):
-        if chunk: # filter out keep-alive new chunks
-            handle.write(chunk)
-    handle.close()
-
 def _copy_files(extract_dest, dest, contents):
     to_copy = {}
     for root, dirs, files in os.walk(extract_dest):
@@ -109,13 +110,17 @@ def ext_extract(abs_source, dest, inputhash, loader, **kwargs):
 
     jsonschema.validate(contents, SCHEMA)
 
+    finalfile = get_filename(dest)
     url = contents['url']
     local_filename = url.split('/')[-1]
 
     tmpfile = tempfile.NamedTemporaryFile(prefix=local_filename, suffix='.download', delete=False)
     to_delete = [tmpfile.name]
     try:
-        _download_file(url, tmpfile)
+        auth = None
+        if 'username' in contents and 'password' in contents:
+            auth = (contents['username'], contents['password'])
+        _download_file(url, tmpfile, auth)
 
         if 'type' in contents:
             extractor = EXTRACTORS[contents['type']]
@@ -125,26 +130,22 @@ def ext_extract(abs_source, dest, inputhash, loader, **kwargs):
                     extractor = EXTRACTORS[k]
                     break
             else:
-                raise UserException('No extractor found for {}'.format(local_filename))
+                raise TypeError('No extractor found for {}'.format(local_filename))
 
         if 'persist' in contents and not contents['persist']:
             extract_dest = tempfile.mkdtemp(prefix=local_filename, suffix='.sq')
             to_delete.append(extract_dest)
             persist = False
         else:
-            extract_dest = dest
+            extract_dest = finalfile
             persist = True
 
         extractor(tmpfile.name, extract_dest)
 
         if 'copy' in contents:
-            _copy_files(extract_dest, dest, contents)
+            _copy_files(extract_dest, finalfile, contents)
 
-        if persist:
-            finalfile = get_filename(dest)
-            return finalfile
-        else:
-            return None
+        return finalfile
     finally:
         for f in to_delete:
             if os.path.isdir(f):
